@@ -92,11 +92,12 @@ class QuickDB:
             end = start
         trdstp = self.getTS(88, start, end).replace({1:0, 0:1})
         liqsell = self.getTS(92, start, end).replace({1:0, 0:1})
-        tradable = (trdstp * liqsell).where(lambda x : x == 1).dropna(axis=1)
-        if tradable.shape[0]:
-            return tradable.columns.to_list()
-        else:
-            return []
+        return trdstp * liqsell
+        # tradable = (trdstp * liqsell).where(lambda x : x == 1).dropna(axis=1)
+        # if tradable.shape[0]:
+        #     return tradable.columns.to_list()
+        # else:
+        #     return []
 
     def _getTrailingYQ(self, yq, n=4):
         y,q = yq[:4], (yq[4:])
